# Automated testing is difficult, since we really want to visually inspect
# the results of the tests.  I have not been able to find a useful automated
# test for this package, so the maintainer should always run this before
# pushing a new version:
#
# gap -l "%%{_gapdir};%%{buildroot}%%{_gapdir}" <<< 'Test("tst/test.tst");'
#
# That test is more useful if the altasrep package is also installed.

%global pkgname Browse

%global bootstrap 1

Name:           gap-pkg-browse
Version:        1.8.6
Release:        0.0%{?dist}
Summary:        GAP browser for 2-dimensional arrays of data

License:        GPLv3+
URL:            http://www.math.rwth-aachen.de/~Browse/
Source0:        http://www.math.rwth-aachen.de/~Browse/%{pkgname}-%{version}.tar.bz2

BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
%if ! 0%{?bootstrap}
BuildRequires:  gap-pkg-atlasrep
BuildRequires:  gap-pkg-ctbllib
%endif
BuildRequires:  gap-pkg-io
BuildRequires:  gcc
%if 0%{?fedora}
BuildRequires:  ghostscript-core
%else
BuildRequires:  ghostscript
%endif
BuildRequires:  ncurses-devel
BuildRequires:  netpbm-progs

Requires:       gap-core

%if 0%{?fedora}
Recommends:     gap-pkg-atlasrep
Recommends:     gap-pkg-io
%endif

# Don't Provide the ncurses glue
%global __provides_exclude_from ncurses\\.so

%description
The motivation for this package was to develop functions for an
interactive display of two-dimensional arrays of data, for example
character tables.  They should be displayed with labeled rows and
columns, the display should allow some markup for fonts or colors, it
should be possible to search for entries, to sort rows or columns, to
hide and unhide information, to bind commands to keys, and so on.

To achieve this our package now provides three levels of functionality,
where in particular the first level may also be used for completely
other types of applications:
- A low level interface to ncurses: This may be interesting for all
  kinds of applications which want to display text with some markup and
  colors, maybe in several windows, using the available capabilities of
  a terminal.
- A medium level interface to a generic function NCurses.BrowseGeneric:
  We introduce a new operation Browse which is meant as an interactive
  version of Display for GAP objects.  Then we provide a generic
  function for browsing two-dimensional arrays of data, handles labels
  for rows and columns, searching, sorting, binding keys to actions,
  etc.  This is for users who want to implement new methods for browsing
  two-dimensional data.
- Applications of these interfaces: We provide some applications of the
  ncurses interface and of the function NCurses.BrowseGeneric.  These
  may be interesting for end users, and also as examples for programmers
  of further applications.  This includes a method for browsing
  character tables, several games, and an interface for demos.

%prep
%setup -q -n %{pkgname}

# Give an executable script a shebang
sed -i '1i#!/bin/sh' bibl/getnewestbibfile

%build
# This is NOT an autoconf-generated configure script
./configure %{_gap_dir}
make %{?_smp_mflags} LDFLAGS="$RPM_LD_FLAGS" GAPPATH="%{_gap_dir}"

# Fix permissions on the shared object
chmod 0755 bin/*/ncurses.so

# Link to main GAP documentation
mkdir ../pkg
ln -s ../%{pkgname} ../pkg
gap -l "$PWD/..;%{_gap_dir}" < makedocrel.g
rm -fr ../pkg

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname} %{buildroot}%{_gap_dir}/pkg

# Remove files that don't need to be installed
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{doc/clean,CHANGES,README,configure,Makefile*}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,toc}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/tst/*~
rm -fr %{buildroot}%{_gap_dir}/pkg/%{pkgname}/src

%files
%doc CHANGES README
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%license doc/GPL
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.6-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 1.8.6-6
- Rebuild for gap 4.8.3

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.8.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 1.8.6-4
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jan 23 2015 Jerry James <loganjerry@gmail.com> - 1.8.6-2
- Add Requires(post) and Requires(postun)
- Mark documentation as such
- Add linker flags

* Fri Jan 16 2015 Jerry James <loganjerry@gmail.com> - 1.8.6-1
- Initial RPM
